@@ -5,7 +5,7 @@ function (x, nlimit=20, ...)
 	Nodes <- unique(c(x$Edges$node1,x$Edges$node2))
 	cat("Number of nodes:",length(Nodes),"\n")
 	Interactions <- unique(paste(x$Edges$node1,x$Edges$node2,sep="."))
-	cat("Number of interactions:",length(Interactions),"\n")
+	cat("Number of interactions:",length(Interactions),"\n\n")
 	cat("Edges preview:\n")
 	print(head(x$Edges,nlimit))
 	cat("\nDEGenes preview:\n")
