@@ -8,5 +8,5 @@ function (filepath="stringgaussnet_networks",overwrite=F,absolute=F,port.number=
 	filepath<-URLencode(filepath)
 	base.url = paste("http://localhost:", toString(port.number), "/v1", sep="")
 	save.url<-paste(base.url,paste("session?file=",filepath,sep=""),sep="/")
-	if (requireNamespace("httr",quietly=TRUE)) {res <- httr::GET(save.url)} else {stop("httr package must be installed to use this function")}
+	if (requireNamespace("httr",quietly=TRUE)) {res <- httr::POST(save.url)} else {stop("httr package must be installed to use this function")}
 }
